@@ -37,6 +37,7 @@
 #include <api/na-core-utils.h>
 #include <api/na-gconf-utils.h>
 
+static void        dump_entry( GConfEntry *entry, void *user_data );
 static GConfValue *read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfValueType type );
 static gboolean    sync_gconf( GConfClient *gconf, gchar **message );
 
@@ -81,43 +82,27 @@ na_gconf_utils_free_subdirs( GSList *subdirs )
 
 /**
  * na_gconf_utils_has_entry:
- * @gconf: a  #GConfClient instance.
- * @path: the full path of a key.
+ * @entries: the list of entries as returned by #na_gconf_utils_get_entries().
  * @entry: the entry to be tested.
  *
- * Returns: %TRUE if the given @entry exists for the given @path,
+ * Returns: %TRUE if the given @entry exists in the specified @entries,
  * %FALSE else.
  */
 gboolean
-na_gconf_utils_has_entry( GConfClient *gconf, const gchar *path, const gchar *entry )
+na_gconf_utils_has_entry( GSList *entries, const gchar *entry )
 {
-	static const gchar *thisfn = "na_gconf_utils_has_entry";
-	gboolean have_entry = FALSE;
-	GError *error = NULL;
-	gchar *key;
-	GConfValue *value;
+	GSList *ie;
 
-	key = g_strdup_printf( "%s/%s", path, entry );
-
-	value = gconf_client_get_without_default( gconf, key, &error );
-
-	if( error ){
-		g_warning( "%s: key=%s, error=%s", thisfn, key, error->message );
-		g_error_free( error );
-		if( value ){
-			gconf_value_free( value );
-			value = NULL;
+	for( ie = entries ; ie ; ie = ie->next ){
+		gchar *key = g_path_get_basename( gconf_entry_get_key( ( GConfEntry * ) ie->data));
+		int res = strcmp( key, entry );
+		g_free( key );
+		if( res == 0 ){
+			return( TRUE );
 		}
 	}
 
-	if( value ){
-		have_entry = TRUE;
-		gconf_value_free( value );
-	}
-
-	g_free( key );
-
-	return( have_entry );
+	return( FALSE );
 }
 
 /**
@@ -295,6 +280,64 @@ na_gconf_utils_get_string_list_from_entries( GSList *entries, const gchar *entry
 	return( found );
 }
 
+/**
+ * na_gconf_utils_dump_entries:
+ * @list: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
+ *
+ * Dumps the content of the entries.
+ */
+void
+na_gconf_utils_dump_entries( GSList *list )
+{
+	g_slist_foreach( list, ( GFunc ) dump_entry, NULL );
+}
+
+static void
+dump_entry( GConfEntry *entry, void *user_data )
+{
+	static const gchar *thisfn = "na_gconf_utils_dump_entry";
+	gchar *str = NULL;
+	gboolean str_free = FALSE;
+
+	gchar *key = g_path_get_basename( gconf_entry_get_key( entry ));
+	GConfValue *value = gconf_entry_get_value( entry );
+
+	if( value ){
+		switch( value->type ){
+			case GCONF_VALUE_STRING:
+				str = ( gchar * ) gconf_value_get_string( value );
+				break;
+
+			case GCONF_VALUE_INT:
+				str = g_strdup_printf( "%d", gconf_value_get_int( value ));
+				str_free = TRUE;
+				break;
+
+			case GCONF_VALUE_FLOAT:
+				str = g_strdup_printf( "%f", gconf_value_get_float( value ));
+				str_free = TRUE;
+				break;
+
+			case GCONF_VALUE_BOOL:
+				str = g_strdup_printf( "%s", gconf_value_get_bool( value ) ? "True":"False" );
+				str_free = TRUE;
+				break;
+
+			default:
+				str = g_strdup( "(undetermined value)" );
+				str_free = TRUE;
+		}
+	}
+
+	g_debug( "%s: key=%s, value=%s", thisfn, key, str );
+
+	if( str_free ){
+		g_free( str );
+	}
+
+	g_free( key );
+}
+
 /**
  * na_gconf_utils_free_entries:
  * @list: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
@@ -308,71 +351,6 @@ na_gconf_utils_free_entries( GSList *list )
 	g_slist_free( list );
 }
 
-/**
- * na_gconf_utils_read_string:
- * @gconf: a #GConfClient instance.
- * @path: the full path to the key.
- * @use_schema: whether to use the default value from schema, or not.
- * @default_value: default value to be used if schema is not used or
- * doesn't exist.
- *
- * Returns: the required string value in a newly allocated string which
- * should be g_free() by the caller.
- */
-gchar *
-na_gconf_utils_read_string( GConfClient *gconf, const gchar *path, gboolean use_schema, const gchar *default_value )
-{
-	GConfValue *value = NULL;
-	gchar *result;
-
-	g_return_val_if_fail( GCONF_IS_CLIENT( gconf ), NULL );
-
-	result = g_strdup( default_value );
-
-	value = read_value( gconf, path, use_schema, GCONF_VALUE_STRING );
-
-	if( value ){
-		g_free( result );
-		result = g_strdup( gconf_value_get_string( value ));
-		gconf_value_free( value );
-	}
-
-	return( result );
-}
-
-static GConfValue *
-read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfValueType type )
-{
-	static const gchar *thisfn = "na_gconf_utils_read_value";
-	GError *error = NULL;
-	GConfValue *value = NULL;
-
-	if( use_schema ){
-		value = gconf_client_get( gconf, path, &error );
-	} else {
-		value = gconf_client_get_without_default( gconf, path, &error );
-	}
-
-	if( error ){
-		g_warning( "%s: path=%s, error=%s", thisfn, path, error->message );
-		g_error_free( error );
-		if( value ){
-			gconf_value_free( value );
-			value = NULL;
-		}
-	}
-
-	if( value ){
-		if( value->type != type ){
-			g_warning( "%s: path=%s, found type '%u' while waiting for type '%u'", thisfn, path, value->type, type );
-			gconf_value_free( value );
-			value = NULL;
-		}
-	}
-
-	return( value );
-}
-
 /**
  * na_gconf_utils_read_bool:
  * @gconf: a #GConfClient instance.
@@ -432,6 +410,38 @@ na_gconf_utils_read_int( GConfClient *gconf, const gchar *path, gboolean use_sch
 	return( ret );
 }
 
+/**
+ * na_gconf_utils_read_string:
+ * @gconf: a #GConfClient instance.
+ * @path: the full path to the key.
+ * @use_schema: whether to use the default value from schema, or not.
+ * @default_value: default value to be used if schema is not used or
+ * doesn't exist.
+ *
+ * Returns: the required string value in a newly allocated string which
+ * should be g_free() by the caller.
+ */
+gchar *
+na_gconf_utils_read_string( GConfClient *gconf, const gchar *path, gboolean use_schema, const gchar *default_value )
+{
+	GConfValue *value = NULL;
+	gchar *result;
+
+	g_return_val_if_fail( GCONF_IS_CLIENT( gconf ), NULL );
+
+	result = g_strdup( default_value );
+
+	value = read_value( gconf, path, use_schema, GCONF_VALUE_STRING );
+
+	if( value ){
+		g_free( result );
+		result = g_strdup( gconf_value_get_string( value ));
+		gconf_value_free( value );
+	}
+
+	return( result );
+}
+
 /**
  * na_gconf_utils_read_string_list:
  * @gconf: a #GConfClient instance.
@@ -705,6 +715,39 @@ na_gconf_utils_slist_to_string( GSList *slist )
 	return( g_string_free( str, FALSE ));
 }
 
+static GConfValue *
+read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfValueType type )
+{
+	static const gchar *thisfn = "na_gconf_utils_read_value";
+	GError *error = NULL;
+	GConfValue *value = NULL;
+
+	if( use_schema ){
+		value = gconf_client_get( gconf, path, &error );
+	} else {
+		value = gconf_client_get_without_default( gconf, path, &error );
+	}
+
+	if( error ){
+		g_warning( "%s: path=%s, error=%s", thisfn, path, error->message );
+		g_error_free( error );
+		if( value ){
+			gconf_value_free( value );
+			value = NULL;
+		}
+	}
+
+	if( value ){
+		if( value->type != type ){
+			g_warning( "%s: path=%s, found type '%u' while waiting for type '%u'", thisfn, path, value->type, type );
+			gconf_value_free( value );
+			value = NULL;
+		}
+	}
+
+	return( value );
+}
+
 static gboolean
 sync_gconf( GConfClient *gconf, gchar **message )
 {
