@@ -179,8 +179,6 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	self = NA_OBJECT_ACTION( instance );
 
 	self->private = g_new0( NAObjectActionPrivate, 1 );
-
-	na_ifactory_object_set_from_void( NA_IFACTORY_OBJECT( instance ), NAFO_DATA_TYPE, ( void * ) "Action" );
 }
 
 static void
@@ -689,7 +687,7 @@ na_object_action_attach_profile( NAObjectAction *action, NAObjectProfile *profil
  *
  * Returns: %TRUE if the @action may be candidate for this @target.
  *
- * Note that this public function will become NAIContextual::is_candidate
+ * Note that this public function will become NAIContext::is_candidate
  * when NAObjectAction will implement the interface.
  */
 gboolean
