@@ -83,7 +83,7 @@ static gboolean     ifactory_object_is_valid( const NAIFactoryObject *object );
 static void         ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages );
 static guint        ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 
-static void         icontext_conditions_iface_init( NAIContextualInterface *iface );
+static void         icontext_conditions_iface_init( NAIContextInterface *iface );
 
 static gboolean     profile_is_valid( const NAObjectProfile *profile );
 static gboolean     is_valid_path_parameters( const NAObjectProfile *profile );
@@ -136,7 +136,7 @@ register_type( void )
 
 	type = g_type_register_static( NA_OBJECT_ID_TYPE, "NAObjectProfile", &info, 0 );
 
-	g_type_add_interface_static( type, NA_ICONTEXTUAL_TYPE, &icontext_conditions_iface_info );
+	g_type_add_interface_static( type, NA_ICONTEXT_TYPE, &icontext_conditions_iface_info );
 
 	g_type_add_interface_static( type, NA_IFACTORY_OBJECT_TYPE, &ifactory_object_iface_info );
 
@@ -337,7 +337,7 @@ ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider
 }
 
 static void
-icontext_conditions_iface_init( NAIContextualInterface *iface )
+icontext_conditions_iface_init( NAIContextInterface *iface )
 {
 	static const gchar *thisfn = "na_object_profile_icontext_conditions_iface_init";
 
@@ -355,7 +355,7 @@ profile_is_valid( const NAObjectProfile *profile )
 
 		is_valid = \
 				is_valid_path_parameters( profile ) &&
-				na_icontextual_is_valid( NA_ICONTEXTUAL( profile ));
+				na_icontext_is_valid( NA_ICONTEXT( profile ));
 	}
 
 	return( is_valid );
@@ -520,7 +520,7 @@ na_object_profile_parse_parameters( const NAObjectProfile *profile, gint target,
 			na_gnome_vfs_uri_parse( vfs, iuri );
 
 			uri = g_strdup( iuri );
-			dirname = g_path_get_dirname( ipath );
+			dirname = ipath ? g_path_get_dirname( ipath ) : NULL;
 			scheme = g_strdup( vfs->scheme );
 			filename = g_strdup( ibname );
 			hostname = g_strdup( vfs->host_name );
@@ -531,13 +531,17 @@ na_object_profile_parse_parameters( const NAObjectProfile *profile, gint target,
 			na_gnome_vfs_uri_free( vfs );
 		}
 
-		tmp = g_shell_quote( ibname );
-		g_string_append_printf( basename_list, " %s", tmp );
-		g_free( tmp );
+		if( ibname ){
+			tmp = g_shell_quote( ibname );
+			g_string_append_printf( basename_list, " %s", tmp );
+			g_free( tmp );
+		}
 
-		tmp = g_shell_quote( ipath );
-		g_string_append_printf( pathname_list, " %s", tmp );
-		g_free( tmp );
+		if( ipath ){
+			tmp = g_shell_quote( ipath );
+			g_string_append_printf( pathname_list, " %s", tmp );
+			g_free( tmp );
+		}
 
 		tmp = g_shell_quote( iuri );
 		g_string_append_printf( uris_list, " %s", tmp );
@@ -560,35 +564,45 @@ na_object_profile_parse_parameters( const NAObjectProfile *profile, gint target,
 			/* base dir of the (first) selected item
 			 */
 			case 'd':
-				tmp = g_shell_quote( dirname );
-				string = g_string_append( string, tmp );
-				g_free( tmp );
+				if( dirname ){
+					tmp = g_shell_quote( dirname );
+					string = g_string_append( string, tmp );
+					g_free( tmp );
+				}
 				break;
 
 			/* basename of the (first) selected item
 			 */
 			case 'f':
-				tmp = g_shell_quote( filename );
-				string = g_string_append( string, tmp );
-				g_free( tmp );
+				if( filename ){
+					tmp = g_shell_quote( filename );
+					string = g_string_append( string, tmp );
+					g_free( tmp );
+				}
 				break;
 
 			/* hostname of the (first) URI
 			 */
 			case 'h':
-				string = g_string_append( string, hostname );
+				if( hostname ){
+					string = g_string_append( string, hostname );
+				}
 				break;
 
 			/* space-separated list of the basenames
 			 */
 			case 'm':
-				string = g_string_append( string, basename_list->str );
+				if( basename_list->str ){
+					string = g_string_append( string, basename_list->str );
+				}
 				break;
 
 			/* space-separated list of full pathnames
 			 */
 			case 'M':
-				string = g_string_append( string, pathname_list->str );
+				if( pathname_list->str ){
+					string = g_string_append( string, pathname_list->str );
+				}
 				break;
 
 			/* port number of the (first) URI
@@ -602,25 +616,33 @@ na_object_profile_parse_parameters( const NAObjectProfile *profile, gint target,
 			/* list of URIs
 			 */
 			case 'R':
-				string = g_string_append( string, uris_list->str );
+				if( uris_list->str ){
+					string = g_string_append( string, uris_list->str );
+				}
 				break;
 
 			/* scheme of the (first) URI
 			 */
 			case 's':
-				string = g_string_append( string, scheme );
+				if( scheme ){
+					string = g_string_append( string, scheme );
+				}
 				break;
 
 			/* URI of the first item
 			 */
 			case 'u':
-				string = g_string_append( string, uri );
+				if( uri ){
+					string = g_string_append( string, uri );
+				}
 				break;
 
 			/* username of the (first) URI
 			 */
 			case 'U':
-				string = g_string_append( string, username );
+				if( username ){
+					string = g_string_append( string, username );
+				}
 				break;
 
 			/* a percent sign
