@@ -35,7 +35,10 @@
 
 G_BEGIN_DECLS
 
-GList *nadp_iio_provider_read_items( const NAIIOProvider *provider, GSList **messages );
+GList       *nadp_iio_provider_read_items( const NAIIOProvider *provider, GSList **messages );
+
+NADataBoxed *nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void *reader_data, const NAIFactoryObject *serializable, const NADataDef *iddef, GSList **messages );
+void         nadp_reader_ifactory_provider_read_done( const NAIFactoryProvider *reader, void *reader_data, const NAIFactoryObject *serializable, GSList **messages );
 
 G_END_DECLS
 
