@@ -4,7 +4,7 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -66,6 +66,13 @@ enum {
 #define BASE_APPLICATION_PROP_ARGC					"base-application-argc"
 #define BASE_APPLICATION_PROP_ARGV					"base-application-argv"
 
+/**
+ * @BASE_APPLICATION_PROP_OPTIONS: command-line options.
+ *
+ * Can be provided at instanciation time only.
+ */
+#define BASE_APPLICATION_PROP_OPTIONS				"base-application-options"
+
 /**
  * @BASE_APPLICATION_PROP_IS_GTK_INITIALIZED: set to %TRUE after
  * successfully returning from the application_initialize_gtk() virtual
