@@ -4,7 +4,7 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,24 +32,20 @@
 #include <config.h>
 #endif
 
-#include <gconf/gconf.h>
 #include <glib/gi18n.h>
-#include <gtk/gtk.h>
 #include <string.h>
 
-#include <runtime/na-iio-provider.h>
-#include <runtime/na-pivot.h>
+#include <api/na-object-api.h>
+#include <api/na-core-utils.h>
 
-#include <common/na-object-api.h>
-#include <common/na-iprefs.h>
-#include <common/na-utils.h>
+#include <core/na-importer.h>
+#include <core/na-iprefs.h>
 
 #include "nact-application.h"
+#include "nact-iprefs.h"
 #include "nact-iactions-list.h"
 #include "nact-assistant-import.h"
-#include "nact-assistant-import-ask.h"
 #include "nact-main-window.h"
-#include "nact-xml-reader.h"
 
 /* Import Assistant
  *
@@ -70,13 +66,23 @@ enum {
 	ASSIST_PAGE_DONE
 };
 
+/* a structure which hosts successfully imported files
+ */
 typedef struct {
-	gchar          *uri;
-	NAObjectAction *action;
-	GSList         *msg;
+	gchar        *uri;
+	NAObjectItem *item;
+	GSList       *msg;
 }
 	ImportUriStruct;
 
+/* a structure to check for existance of imported items
+ */
+typedef struct {
+	NactMainWindow *window;
+	GList          *imported;
+}
+	ImportCheck;
+
 /* private class data
  */
 struct NactAssistantImportClassPrivate {
@@ -86,41 +92,42 @@ struct NactAssistantImportClassPrivate {
 /* private instance data
  */
 struct NactAssistantImportPrivate {
-	gboolean  dispose_has_run;
-	GSList   *results;
-	GSList   *actions;
+	gboolean     dispose_has_run;
+	GConfClient *gconf;
+	GSList      *results;
+	GList       *items;
 };
 
-#define IPREFS_IMPORT_ACTIONS_FOLDER_URI		"import-folder-uri"
-
 static BaseAssistantClass *st_parent_class = NULL;
 
-static GType    register_type( void );
-static void     class_init( NactAssistantImportClass *klass );
-static void     instance_init( GTypeInstance *instance, gpointer klass );
-static void     instance_dispose( GObject *application );
-static void     instance_finalize( GObject *application );
+static GType         register_type( void );
+static void          class_init( NactAssistantImportClass *klass );
+static void          instance_init( GTypeInstance *instance, gpointer klass );
+static void          instance_dispose( GObject *application );
+static void          instance_finalize( GObject *application );
 
 static NactAssistantImport *assist_new( BaseWindow *parent );
 
-static gchar   *window_get_iprefs_window_id( BaseWindow *window );
-static gchar   *window_get_dialog_name( BaseWindow *dialog );
+static gchar        *window_get_iprefs_window_id( const BaseWindow *window );
+static gchar        *window_get_dialog_name( const BaseWindow *dialog );
 
-static void     on_runtime_init_dialog( NactAssistantImport *dialog, gpointer user_data );
-static void     runtime_init_intro( NactAssistantImport *window, GtkAssistant *assistant );
-static void     runtime_init_file_selector( NactAssistantImport *window, GtkAssistant *assistant );
-static void     on_file_selection_changed( GtkFileChooser *chooser, gpointer user_data );
-static gboolean has_readable_files( GSList *uris );
-static void     runtime_init_duplicates( NactAssistantImport *window, GtkAssistant *assistant );
-static void     set_import_mode( NactAssistantImport *window, gint mode );
+static void          on_initial_load_dialog( NactAssistantImport *dialog, gpointer user_data );
+static void          on_runtime_init_dialog( NactAssistantImport *dialog, gpointer user_data );
+static void          runtime_init_intro( NactAssistantImport *window, GtkAssistant *assistant );
+static void          runtime_init_file_selector( NactAssistantImport *window, GtkAssistant *assistant );
+static void          on_file_selection_changed( GtkFileChooser *chooser, gpointer user_data );
+static gboolean      has_readable_files( GSList *uris );
+static void          runtime_init_duplicates( NactAssistantImport *window, GtkAssistant *assistant );
+static void          set_import_mode( NactAssistantImport *window, gint mode );
 
-static void     assistant_prepare( BaseAssistant *window, GtkAssistant *assistant, GtkWidget *page );
-static void     prepare_confirm( NactAssistantImport *window, GtkAssistant *assistant, GtkWidget *page );
-static gint     get_import_mode( NactAssistantImport *window );
-static gchar   *add_import_mode( NactAssistantImport *window, const gchar *text );
-static void     assistant_apply( BaseAssistant *window, GtkAssistant *assistant );
-static void     prepare_importdone( NactAssistantImport *window, GtkAssistant *assistant, GtkWidget *page );
-static void     free_results( GSList *list );
+static void          assistant_prepare( BaseAssistant *window, GtkAssistant *assistant, GtkWidget *page );
+static void          prepare_confirm( NactAssistantImport *window, GtkAssistant *assistant, GtkWidget *page );
+static gint          get_import_mode( NactAssistantImport *window );
+static gchar        *add_import_mode( NactAssistantImport *window, const gchar *text );
+static void          assistant_apply( BaseAssistant *window, GtkAssistant *assistant );
+static NAObjectItem *check_for_existance( const NAObjectItem *, ImportCheck *check );
+static void          prepare_importdone( NactAssistantImport *window, GtkAssistant *assistant, GtkWidget *page );
+static void          free_results( GSList *list );
 
 GType
 nact_assistant_import_get_type( void )
@@ -192,20 +199,30 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	static const gchar *thisfn = "nact_assistant_import_instance_init";
 	NactAssistantImport *self;
 
-	g_debug( "%s: instance=%p, klass=%p", thisfn, ( void * ) instance, ( void * ) klass );
+	g_debug( "%s: instance=%p (%s), klass=%p",
+			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
 	g_return_if_fail( NACT_IS_ASSISTANT_IMPORT( instance ));
 	self = NACT_ASSISTANT_IMPORT( instance );
 
 	self->private = g_new0( NactAssistantImportPrivate, 1 );
 
-	self->private->dispose_has_run = FALSE;
 	self->private->results = NULL;
 
+	base_window_signal_connect(
+			BASE_WINDOW( instance ),
+			G_OBJECT( instance ),
+			BASE_WINDOW_SIGNAL_INITIAL_LOAD,
+			G_CALLBACK( on_initial_load_dialog ));
+
 	base_window_signal_connect(
 			BASE_WINDOW( instance ),
 			G_OBJECT( instance ),
 			BASE_WINDOW_SIGNAL_RUNTIME_INIT,
 			G_CALLBACK( on_runtime_init_dialog ));
+
+	self->private->gconf = gconf_client_get_default();
+
+	self->private->dispose_has_run = FALSE;
 }
 
 static void
@@ -214,7 +231,7 @@ instance_dispose( GObject *window )
 	static const gchar *thisfn = "nact_assistant_import_instance_dispose";
 	NactAssistantImport *self;
 
-	g_debug( "%s: window=%p", thisfn, ( void * ) window );
+	g_debug( "%s: window=%p (%s)", thisfn, ( void * ) window, G_OBJECT_TYPE_NAME( window ));
 	g_return_if_fail( NACT_IS_ASSISTANT_IMPORT( window ));
 	self = NACT_ASSISTANT_IMPORT( window );
 
@@ -222,6 +239,8 @@ instance_dispose( GObject *window )
 
 		self->private->dispose_has_run = TRUE;
 
+		g_object_unref( self->private->gconf );
+
 		/* chain up to the parent class */
 		if( G_OBJECT_CLASS( st_parent_class )->dispose ){
 			G_OBJECT_CLASS( st_parent_class )->dispose( window );
@@ -273,17 +292,36 @@ nact_assistant_import_run( BaseWindow *main_window )
 }
 
 static gchar *
-window_get_iprefs_window_id( BaseWindow *window )
+window_get_iprefs_window_id( const BaseWindow *window )
 {
 	return( g_strdup( "import-assistant" ));
 }
 
 static gchar *
-window_get_dialog_name( BaseWindow *dialog )
+window_get_dialog_name( const BaseWindow *dialog )
 {
 	return( g_strdup( "ImportAssistant" ));
 }
 
+static void
+on_initial_load_dialog( NactAssistantImport *dialog, gpointer user_data )
+{
+	static const gchar *thisfn = "nact_assistant_import_on_initial_load_dialog";
+	NactApplication *application;
+	NAUpdater *updater;
+	gboolean esc_quit, esc_confirm;
+
+	g_debug( "%s: dialog=%p, user_data=%p", thisfn, ( void * ) dialog, ( void * ) user_data );
+	g_return_if_fail( NACT_IS_ASSISTANT_IMPORT( dialog ));
+
+	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( dialog )));
+	updater = nact_application_get_updater( application );
+	esc_quit = na_iprefs_read_bool( NA_IPREFS( updater ), IPREFS_ASSIST_ESC_QUIT, TRUE );
+	base_assistant_set_cancel_on_esc( BASE_ASSISTANT( dialog ), esc_quit );
+	esc_confirm = na_iprefs_read_bool( NA_IPREFS( updater ), IPREFS_ASSIST_ESC_CONFIRM, TRUE );
+	base_assistant_set_warn_on_esc( BASE_ASSISTANT( dialog ), esc_confirm );
+}
+
 static void
 on_runtime_init_dialog( NactAssistantImport *dialog, gpointer user_data )
 {
@@ -295,9 +333,6 @@ on_runtime_init_dialog( NactAssistantImport *dialog, gpointer user_data )
 
 	if( !dialog->private->dispose_has_run ){
 
-		base_assistant_set_cancel_on_esc( BASE_ASSISTANT( dialog ), TRUE );
-		base_assistant_set_warn_on_esc( BASE_ASSISTANT( dialog ), TRUE );
-
 		assistant = GTK_ASSISTANT( base_window_get_toplevel( BASE_WINDOW( dialog )));
 
 		runtime_init_intro( dialog, assistant );
@@ -325,7 +360,7 @@ runtime_init_file_selector( NactAssistantImport *window, GtkAssistant *assistant
 {
 	static const gchar *thisfn = "nact_assistant_import_runtime_init_file_selector";
 	NactApplication *application;
-	NAPivot *pivot;
+	NAUpdater *updater;
 	GtkWidget *page;
 	GtkWidget *chooser;
 	gchar *uri;
@@ -336,10 +371,10 @@ runtime_init_file_selector( NactAssistantImport *window, GtkAssistant *assistant
 			thisfn, ( void * ) window, ( void * ) assistant, ( void * ) page );
 
 	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
-	pivot = nact_application_get_pivot( application );
+	updater = nact_application_get_updater( application );
 
 	chooser = base_window_get_widget( BASE_WINDOW( window ), "ImportFileChooser" );
-	uri = na_iprefs_read_string( NA_IPREFS( pivot ), IPREFS_IMPORT_ACTIONS_FOLDER_URI, "file:///tmp" );
+	uri = na_iprefs_read_string( NA_IPREFS( updater ), IPREFS_IMPORT_ITEMS_FOLDER_URI, "file:///tmp" );
 	if( uri && strlen( uri )){
 		gtk_file_chooser_set_current_folder_uri( GTK_FILE_CHOOSER( chooser ), uri );
 	}
@@ -361,8 +396,6 @@ on_file_selection_changed( GtkFileChooser *chooser, gpointer user_data )
 	g_debug( "%s: chooser=%p, user_data=%p", thisfn, chooser, user_data );*/
 
 	GtkAssistant *assistant;
-	NactApplication *application;
-	NAPivot *pivot;
 	gint pos;
 	GSList *uris;
 	gboolean enabled;
@@ -379,13 +412,11 @@ on_file_selection_changed( GtkFileChooser *chooser, gpointer user_data )
 
 		if( enabled ){
 			folder = gtk_file_chooser_get_current_folder_uri( GTK_FILE_CHOOSER( chooser ));
-			application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( user_data )));
-			pivot = nact_application_get_pivot( application );
-			na_iprefs_write_string( NA_IPREFS( pivot ), IPREFS_IMPORT_ACTIONS_FOLDER_URI, folder );
+			nact_iprefs_write_string( BASE_WINDOW( user_data ), IPREFS_IMPORT_ITEMS_FOLDER_URI, folder );
 			g_free( folder );
 		}
 
-		na_utils_free_string_list( uris );
+		na_core_utils_slist_free( uris );
 
 		content = gtk_assistant_get_nth_page( assistant, pos );
 		gtk_assistant_set_page_complete( assistant, content, enabled );
@@ -450,16 +481,12 @@ static void
 runtime_init_duplicates( NactAssistantImport *window, GtkAssistant *assistant )
 {
 	static const gchar *thisfn = "nact_assistant_import_runtime_init_duplicates";
-	NactApplication *application;
-	NAPivot *pivot;
 	GtkWidget *page;
-	gint mode;
+	guint mode;
 
 	g_debug( "%s: window=%p", thisfn, ( void * ) window );
 
-	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
-	pivot = nact_application_get_pivot( application );
-	mode = na_iprefs_get_import_mode( NA_IPREFS( pivot ), IPREFS_IMPORT_ACTIONS_IMPORT_MODE );
+	mode = na_iprefs_get_import_mode( window->private->gconf, IPREFS_IMPORT_ITEMS_IMPORT_MODE );
 	set_import_mode( window, mode );
 
 	page = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_DUPLICATES );
@@ -472,22 +499,22 @@ set_import_mode( NactAssistantImport *window, gint mode )
 	GtkToggleButton *button;
 
 	switch( mode ){
-		case IPREFS_IMPORT_ASK:
+		case IMPORTER_MODE_ASK:
 			button = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "AskButton" ));
 			gtk_toggle_button_set_active( button, TRUE );
 			break;
 
-		case IPREFS_IMPORT_RENUMBER:
+		case IMPORTER_MODE_RENUMBER:
 			button = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "RenumberButton" ));
 			gtk_toggle_button_set_active( button, TRUE );
 			break;
 
-		case IPREFS_IMPORT_OVERRIDE:
+		case IMPORTER_MODE_OVERRIDE:
 			button = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "OverrideButton" ));
 			gtk_toggle_button_set_active( button, TRUE );
 			break;
 
-		case IPREFS_IMPORT_NO_IMPORT:
+		case IMPORTER_MODE_NO_IMPORT:
 		default:
 			button = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "NoImportButton" ));
 			gtk_toggle_button_set_active( button, TRUE );
@@ -527,6 +554,7 @@ prepare_confirm( NactAssistantImport *window, GtkAssistant *assistant, GtkWidget
 	gchar *text, *tmp;
 	GtkWidget *chooser;
 	GSList *uris, *is;
+	GtkLabel *confirm_label;
 
 	g_debug( "%s: window=%p, assistant=%p, page=%p",
 			thisfn, ( void * ) window, ( void * ) assistant, ( void * ) page );
@@ -550,7 +578,8 @@ prepare_confirm( NactAssistantImport *window, GtkAssistant *assistant, GtkWidget
 	g_free( text );
 	text = tmp;
 
-	gtk_label_set_markup( GTK_LABEL( page ), text );
+	confirm_label = GTK_LABEL( base_window_get_widget( BASE_WINDOW( window ), "AssistantImportConfirmLabel" ));
+	gtk_label_set_markup( confirm_label, text );
 	g_free( text );
 
 	gtk_assistant_set_page_complete( assistant, page, TRUE );
@@ -570,13 +599,15 @@ get_import_mode( NactAssistantImport *window )
 	override_button = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "OverrideButton" ));
 	ask_button = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "AskButton" ));
 
-	mode = IPREFS_IMPORT_NO_IMPORT;
+	mode = IMPORTER_MODE_NO_IMPORT;
 	if( gtk_toggle_button_get_active( renumber_button )){
-		mode = IPREFS_IMPORT_RENUMBER;
+		mode = IMPORTER_MODE_RENUMBER;
+
 	} else if( gtk_toggle_button_get_active( override_button )){
-		mode = IPREFS_IMPORT_OVERRIDE;
+		mode = IMPORTER_MODE_OVERRIDE;
+
 	} else if( gtk_toggle_button_get_active( ask_button )){
-		mode = IPREFS_IMPORT_ASK;
+		mode = IMPORTER_MODE_ASK;
 	}
 
 	return( mode );
@@ -595,23 +626,23 @@ add_import_mode( NactAssistantImport *window, const gchar *text )
 	result = NULL;
 
 	switch( mode ){
-		case IPREFS_IMPORT_NO_IMPORT:
-			label1 = g_strdup( gtk_button_get_label( GTK_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "NoImportButton" ))));
+		case IMPORTER_MODE_NO_IMPORT:
+			label1 = na_core_utils_str_remove_char( gtk_button_get_label( GTK_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "NoImportButton" ))), "_" );
 			label2 = g_strdup( gtk_label_get_text( GTK_LABEL( base_window_get_widget( BASE_WINDOW( window ), "NoImportLabel"))));
 			break;
 
-		case IPREFS_IMPORT_RENUMBER:
-			label1 = g_strdup( gtk_button_get_label( GTK_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "RenumberButton" ))));
+		case IMPORTER_MODE_RENUMBER:
+			label1 = na_core_utils_str_remove_char( gtk_button_get_label( GTK_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "RenumberButton" ))), "_" );
 			label2 = g_strdup( gtk_label_get_text( GTK_LABEL( base_window_get_widget( BASE_WINDOW( window ), "RenumberLabel"))));
 			break;
 
-		case IPREFS_IMPORT_OVERRIDE:
-			label1 = g_strdup( gtk_button_get_label( GTK_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "OverrideButton" ))));
+		case IMPORTER_MODE_OVERRIDE:
+			label1 = na_core_utils_str_remove_char( gtk_button_get_label( GTK_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "OverrideButton" ))), "_" );
 			label2 = g_strdup( gtk_label_get_text( GTK_LABEL( base_window_get_widget( BASE_WINDOW( window ), "OverrideLabel"))));
 			break;
 
-		case IPREFS_IMPORT_ASK:
-			label1 = g_strdup( gtk_button_get_label( GTK_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "AskButton" ))));
+		case IMPORTER_MODE_ASK:
+			label1 = na_core_utils_str_remove_char( gtk_button_get_label( GTK_BUTTON( base_window_get_widget( BASE_WINDOW( window ), "AskButton" ))), "_" );
 			label2 = g_strdup( gtk_label_get_text( GTK_LABEL( base_window_get_widget( BASE_WINDOW( window ), "AskLabel"))));
 			break;
 
@@ -620,7 +651,7 @@ add_import_mode( NactAssistantImport *window, const gchar *text )
 	}
 
 	if( label1 ){
-		label3 = na_utils_prefix_strings( "\t", label2 );
+		label3 = na_core_utils_str_add_prefix( "\t", label2 );
 		g_free( label2 );
 
 		result = g_strdup_printf( "%s\n\n<b>%s</b>\n\n%s", text, label1, label3 );
@@ -640,12 +671,16 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
 	static const gchar *thisfn = "nact_assistant_import_assistant_apply";
 	NactAssistantImport *window;
 	GtkWidget *chooser;
-	GSList *uris, *is, *msg;
-	NAObjectAction *action;
+	GSList *uris, *is;
 	ImportUriStruct *str;
-	GList *items;
+	GList *imported_items;
 	BaseWindow *mainwnd;
-	gint mode;
+	guint mode;
+	NactApplication *application;
+	NAUpdater *updater;
+	NAIImporterUriParms parms;
+	guint code;
+	ImportCheck check_str;
 
 	g_debug( "%s: window=%p, assistant=%p", thisfn, ( void * ) wnd, ( void * ) assistant );
 	g_assert( NACT_IS_ASSISTANT_IMPORT( wnd ));
@@ -657,59 +692,98 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
 
 	g_object_get( G_OBJECT( wnd ), BASE_WINDOW_PROP_PARENT, &mainwnd, NULL );
 
+	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( wnd )));
+	updater = nact_application_get_updater( application );
+	imported_items = NULL;
+	check_str.window = NACT_MAIN_WINDOW( mainwnd );
+	check_str.imported = imported_items;
+
 	/* import actions
 	 * getting results in the same order than uris
 	 * simultaneously building the actions list
 	 */
-	items = NULL;
 	for( is = uris ; is ; is = is->next ){
 
-		msg = NULL;
-		action = nact_xml_reader_import( BASE_WINDOW( window ), items, ( const gchar * ) is->data, mode, &msg );
+		parms.version = 1;
+		parms.uri = ( gchar * ) is->data;
+		parms.mode = mode;
+		parms.window = base_window_get_toplevel( base_application_get_main_window( BASE_APPLICATION( application )));
+		parms.messages = NULL;
+		parms.imported = NULL;
+		parms.check_fn = ( NAIImporterCheckFn ) check_for_existance;
+		parms.check_fn_data = &check_str;
+
+		code = na_importer_import_from_uri( NA_PIVOT( updater ), &parms );
 
 		str = g_new0( ImportUriStruct, 1 );
-		str->uri = g_strdup(( const gchar * ) is->data );
-		str->action = action;
-		str->msg = na_utils_duplicate_string_list( msg );
-		na_utils_free_string_list( msg );
+		str->uri = g_strdup( parms.uri );
+		str->item = parms.imported;
+		str->msg = na_core_utils_slist_duplicate( parms.messages );
+		na_core_utils_slist_free( parms.messages );
 
-		if( str->action ){
-			na_object_check_status( str->action );
-			items = g_list_prepend( items, str->action );
+		if( str->item ){
+			na_object_check_status( str->item );
+			imported_items = g_list_prepend( imported_items, str->item );
 		}
 
 		window->private->results = g_slist_prepend( window->private->results, str );
 	}
-	na_utils_free_string_list( uris );
+	na_core_utils_slist_free( uris );
 	window->private->results = g_slist_reverse( window->private->results );
 
 	/* then insert the list
 	 * assuring that actions will be inserted in the same order as uris
 	 */
-	items = g_list_reverse( items );
-	nact_iactions_list_insert_items( NACT_IACTIONS_LIST( mainwnd ), items, NULL );
-	na_object_free_items_list( items );
+	imported_items = g_list_reverse( imported_items );
+	nact_iactions_list_bis_insert_items( NACT_IACTIONS_LIST( mainwnd ), imported_items, NULL );
+	na_object_unref_items( imported_items );
+}
+
+static NAObjectItem *
+check_for_existance( const NAObjectItem *item, ImportCheck *check )
+{
+	NAObjectItem *exists;
+	GList *ip;
+
+	exists = NULL;
+	gchar *importing_id = na_object_get_id( item );
+	g_debug( "nact_assistant_import_check_for_existance: item=%p (%s), importing_id=%s",
+			( void * ) item, G_OBJECT_TYPE_NAME( item ), importing_id );
+
+	/* is the importing item already in the current importation list ?
+	 */
+	for( ip = check->imported ; ip && !exists ; ip = ip->next ){
+		gchar *id = na_object_get_id( ip->data );
+		if( !strcmp( importing_id, id )){
+			exists = NA_OBJECT_ITEM( ip->data );
+		}
+		g_free( id );
+	}
+
+	if( !exists ){
+		exists = nact_main_window_get_item( check->window, importing_id );
+	}
+
+	g_free( importing_id );
+
+	return( exists );
 }
 
 static void
 prepare_importdone( NactAssistantImport *window, GtkAssistant *assistant, GtkWidget *page )
 {
 	static const gchar *thisfn = "nact_assistant_import_prepare_importdone";
-	NactApplication *application;
-	NAPivot *pivot;
 	gchar *text, *tmp, *text2;
 	gchar *bname, *uuid, *label;
 	GSList *is, *im;
 	ImportUriStruct *str;
 	GFile *file;
-	gint mode;
+	guint mode;
+	GtkLabel *summary_label;
 
 	g_debug( "%s: window=%p, assistant=%p, page=%p",
 			thisfn, ( void * ) window, ( void * ) assistant, ( void * ) page );
 
-	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
-	pivot = nact_application_get_pivot( application );
-
 	/* i18n: result of the import assistant */
 	text = g_strdup( _( "Selected files have been proceeded :" ));
 	tmp = g_strdup_printf( "<b>%s</b>\n\n", text );
@@ -727,13 +801,13 @@ prepare_importdone( NactAssistantImport *window, GtkAssistant *assistant, GtkWid
 		text = tmp;
 		g_free( bname );
 
-		if( str->action ){
+		if( str->item ){
 			/* i18n: indicate that the file has been successfully imported */
 			tmp = g_strdup_printf( "%s\t\t%s\n", text, _( "Import OK" ));
 			g_free( text );
 			text = tmp;
-			uuid = na_object_get_id( str->action );
-			label = na_object_get_label( str->action );
+			uuid = na_object_get_id( str->item );
+			label = na_object_get_label( str->item );
 			/* i18n: this is the globally unique identifier and the label of the newly imported action */
 			text2 = g_strdup_printf( _( "UUID: %s\t%s" ), uuid, label);
 			g_free( label );
@@ -742,7 +816,7 @@ prepare_importdone( NactAssistantImport *window, GtkAssistant *assistant, GtkWid
 			g_free( text );
 			text = tmp;
 
-			window->private->actions = g_slist_prepend( window->private->actions, str->action );
+			window->private->items = g_list_prepend( window->private->items, str->item );
 
 		} else {
 			/* i18n: indicate that the file was not iported */
@@ -764,12 +838,12 @@ prepare_importdone( NactAssistantImport *window, GtkAssistant *assistant, GtkWid
 		text = tmp;
 	}
 
-	/*g_debug( "%s: text='%s'", thisfn, text );*/
-	gtk_label_set_markup( GTK_LABEL( page ), text );
+	summary_label = GTK_LABEL( base_window_get_widget( BASE_WINDOW( window ), "AssistantImportSummaryLabel" ));
+	gtk_label_set_markup( summary_label, text );
 	g_free( text );
 
 	mode = get_import_mode( window );
-	na_iprefs_set_import_mode( NA_IPREFS( pivot ), IPREFS_IMPORT_ACTIONS_IMPORT_MODE, mode );
+	na_iprefs_set_import_mode( window->private->gconf, IPREFS_IMPORT_ITEMS_IMPORT_MODE, mode );
 
 	gtk_assistant_set_page_complete( assistant, page, TRUE );
 	base_assistant_set_warn_on_cancel( BASE_ASSISTANT( window ), FALSE );
@@ -785,7 +859,7 @@ free_results( GSList *list )
 	for( is = list ; is ; is = is->next ){
 		str = ( ImportUriStruct * ) is->data;
 		g_free( str->uri );
-		na_utils_free_string_list( str->msg );
+		na_core_utils_slist_free( str->msg );
 	}
 
 	g_slist_free( list );
