@@ -35,12 +35,15 @@
 #include <glib/gi18n.h>
 #include <string.h>
 
+#include <api/na-core-utils.h>
 #include <api/na-object-api.h>
 
 #include <core/na-io-provider.h>
 
+#include "base-iprefs.h"
 #include "base-window.h"
 #include "nact-application.h"
+#include "nact-iprefs.h"
 #include "nact-main-statusbar.h"
 #include "nact-gtk-utils.h"
 #include "nact-iactions-list.h"
@@ -61,6 +64,9 @@ enum {
 	ICON_N_COLUMN
 };
 
+#define IPREFS_ICONS_DIALOG					"icons-chooser"
+#define IPREFS_ICONS_PATH					"icons-path"
+
 /* IActionTab properties, set against the GObject instance
  */
 #define IACTION_TAB_PROP_STATUS_CONTEXT		"nact-iaction-tab-status-context"
@@ -463,6 +469,7 @@ on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selecte
 		enable_label = ( item && ( NA_IS_OBJECT_MENU( item ) || target_selection || target_location ));
 		label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionMenuLabelEntry" );
 		label = item ? na_object_get_label( item ) : g_strdup( "" );
+		label = label ? label : g_strdup( "" );
 		gtk_entry_set_text( GTK_ENTRY( label_widget ), label );
 		if( item ){
 			check_for_label( instance, GTK_ENTRY( label_widget ), label );
@@ -484,6 +491,7 @@ on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selecte
 
 		label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionToolbarLabelEntry" );
 		label = item && NA_IS_OBJECT_ACTION( item ) ? na_object_get_toolbar_label( item ) : g_strdup( "" );
+		label = label ? label : g_strdup( "" );
 		gtk_entry_set_text( GTK_ENTRY( label_widget ), label );
 		g_free( label );
 		toolbar_label_set_sensitive( instance, item );
@@ -491,6 +499,7 @@ on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selecte
 
 		tooltip_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionTooltipEntry" );
 		tooltip = item ? na_object_get_tooltip( item ) : g_strdup( "" );
+		tooltip = tooltip ? tooltip : g_strdup( "" );
 		gtk_entry_set_text( GTK_ENTRY( tooltip_widget ), tooltip );
 		g_free( tooltip );
 		gtk_widget_set_sensitive( tooltip_widget, item != NULL );
@@ -498,6 +507,7 @@ on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selecte
 
 		icon_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionIconComboBoxEntry" );
 		icon = item ? na_object_get_icon( item ) : g_strdup( "" );
+		icon = icon ? icon : g_strdup( "" );
 		gtk_entry_set_text( GTK_ENTRY( GTK_BIN( icon_widget )->child ), icon );
 		g_free( icon );
 		gtk_widget_set_sensitive( icon_widget, item != NULL );
@@ -879,7 +889,6 @@ create_stock_icon_model( void )
 	model = gtk_list_store_new( ICON_N_COLUMN, G_TYPE_STRING, G_TYPE_STRING );
 
 	gtk_list_store_append( model, &row );
-
 	/* i18n notes: when no icon is selected in the drop-down list */
 	gtk_list_store_set( model, &row, ICON_STOCK_COLUMN, "", ICON_LABEL_COLUMN, _( "None" ), -1 );
 
@@ -935,6 +944,9 @@ on_icon_browse( GtkButton *button, NactIActionTab *instance )
 	GtkWindow *toplevel;
 	gchar *filename;
 	GtkWidget *icon_widget;
+	NactApplication *application;
+	NAUpdater *updater;
+	gchar *path;
 
 	toplevel = base_window_get_toplevel( BASE_WINDOW( instance ));
 
@@ -947,13 +959,30 @@ on_icon_browse( GtkButton *button, NactIActionTab *instance )
 			NULL
 			);
 
+	base_iprefs_position_named_window( BASE_WINDOW( instance ), GTK_WINDOW( dialog ), IPREFS_ICONS_DIALOG );
+
+	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( instance )));
+	updater = nact_application_get_updater( application );
+
+	path = na_iprefs_read_string( NA_IPREFS( updater ), IPREFS_ICONS_PATH, "" );
+	if( path && g_utf8_strlen( path, -1 )){
+		gtk_file_chooser_set_current_folder( GTK_FILE_CHOOSER( dialog ), path );
+	}
+	g_free( path );
+
 	if( gtk_dialog_run( GTK_DIALOG( dialog )) == GTK_RESPONSE_ACCEPT ){
 		filename = gtk_file_chooser_get_filename( GTK_FILE_CHOOSER( dialog ));
 		icon_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionIconComboBoxEntry" );
 		gtk_entry_set_text( GTK_ENTRY( GTK_BIN( icon_widget )->child ), filename );
 	    g_free (filename);
+
+		path = gtk_file_chooser_get_current_folder( GTK_FILE_CHOOSER( dialog ));
+	    nact_iprefs_write_string( BASE_WINDOW( instance ), IPREFS_ICONS_PATH, path );
+		g_free( path );
 	  }
 
+	base_iprefs_save_named_window_position( BASE_WINDOW( instance ), GTK_WINDOW( dialog ), IPREFS_ICONS_DIALOG );
+
 	gtk_widget_destroy( dialog );
 }
 
@@ -962,7 +991,6 @@ on_icon_changed( GtkEntry *icon_entry, NactIActionTab *instance )
 {
 	static const gchar *thisfn = "nact_iaction_tab_on_icon_changed";
 	GtkImage *image;
-	GdkPixbuf *pixbuf;
 	NAObjectItem *edited;
 	const gchar *icon_name;
 
@@ -981,13 +1009,8 @@ on_icon_changed( GtkEntry *icon_entry, NactIActionTab *instance )
 		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, edited, TRUE );
 	}
 
-	pixbuf = nact_gtk_utils_get_pixbuf( icon_name, GTK_ICON_SIZE_MENU );
-
-	if( pixbuf ){
-		image = GTK_IMAGE( base_window_get_widget( BASE_WINDOW( instance ), "ActionIconImage" ));
-		g_assert( GTK_IS_WIDGET( image ));
-		gtk_image_set_from_pixbuf( image, pixbuf );
-	}
+	image = GTK_IMAGE( base_window_get_widget( BASE_WINDOW( instance ), "ActionIconImage" ));
+	nact_gtk_utils_render( icon_name, image, GTK_ICON_SIZE_MENU );
 }
 
 static gint
@@ -1014,7 +1037,7 @@ sort_stock_ids( gconstpointer a, gconstpointer b )
 	} else {
 		label_a = strip_underscore( stock_item_a.label );
 		label_b = strip_underscore( stock_item_b.label );
-		retv = g_utf8_collate( label_a, label_b );
+		retv = na_core_utils_str_collate( label_a, label_b );
 		g_free( label_a );
 		g_free( label_b );
 	}
