@@ -4,7 +4,7 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -35,14 +35,17 @@
 #include <glib/gi18n.h>
 #include <string.h>
 
-#include <common/na-object-api.h>
-#include <common/na-iprefs.h>
-#include <common/na-utils.h>
+#include <api/na-core-utils.h>
+#include <api/na-object-api.h>
+
+#include <core/na-iprefs.h>
 
 #include "base-window.h"
 #include "base-iprefs.h"
 #include "nact-application.h"
 #include "nact-main-statusbar.h"
+#include "nact-gtk-utils.h"
+#include "nact-iprefs.h"
 #include "nact-iactions-list.h"
 #include "nact-main-tab.h"
 #include "nact-icommand-tab.h"
@@ -68,6 +71,7 @@ struct NactICommandTabInterfacePrivate {
 
 static gboolean st_initialized = FALSE;
 static gboolean st_finalized = FALSE;
+static gboolean st_on_selection_change = FALSE;
 
 static GType      register_type( void );
 static void       interface_base_init( NactICommandTabInterface *klass );
@@ -140,6 +144,7 @@ interface_base_init( NactICommandTabInterface *klass )
 	static const gchar *thisfn = "nact_icommand_tab_interface_base_init";
 
 	if( !st_initialized ){
+
 		g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
 		klass->private = g_new0( NactICommandTabInterfacePrivate, 1 );
@@ -153,12 +158,13 @@ interface_base_finalize( NactICommandTabInterface *klass )
 {
 	static const gchar *thisfn = "nact_icommand_tab_interface_base_finalize";
 
-	if( !st_finalized ){
+	if( st_initialized && !st_finalized ){
+
 		g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
-		g_free( klass->private );
-
 		st_finalized = TRUE;
+
+		g_free( klass->private );
 	}
 }
 
@@ -176,20 +182,15 @@ void
 nact_icommand_tab_initial_load_toplevel( NactICommandTab *instance )
 {
 	static const gchar *thisfn = "nact_icommand_tab_initial_load_toplevel";
-	NactApplication *application;
-	NAPivot *pivot;
 
 	g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
 	g_return_if_fail( NACT_IS_ICOMMAND_TAB( instance ));
 
 	if( st_initialized && !st_finalized ){
 
-		application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( instance )));
-		pivot = nact_application_get_pivot( application );
-
-		na_iprefs_migrate_key( NA_IPREFS( pivot ), "iconditions-legend-dialog", IPREFS_LEGEND_DIALOG );
-		na_iprefs_migrate_key( NA_IPREFS( pivot ), "iconditions-command-chooser", IPREFS_COMMAND_CHOOSER );
-		na_iprefs_migrate_key( NA_IPREFS( pivot ), "iconditions-folder-uri", IPREFS_FOLDER_URI );
+		nact_iprefs_migrate_key( BASE_WINDOW( instance ), "iconditions-legend-dialog", IPREFS_LEGEND_DIALOG );
+		nact_iprefs_migrate_key( BASE_WINDOW( instance ), "iconditions-command-chooser", IPREFS_COMMAND_CHOOSER );
+		nact_iprefs_migrate_key( BASE_WINDOW( instance ), "iconditions-folder-uri", IPREFS_FOLDER_URI );
 	}
 }
 
@@ -213,51 +214,51 @@ nact_icommand_tab_runtime_init_toplevel( NactICommandTab *instance )
 	if( st_initialized && !st_finalized ){
 
 		label_entry = get_label_entry( instance );
-		g_signal_connect(
+		base_window_signal_connect(
+				BASE_WINDOW( instance ),
 				G_OBJECT( label_entry ),
 				"changed",
-				G_CALLBACK( on_label_changed ),
-				instance );
+				G_CALLBACK( on_label_changed ));
 
 		path_entry = get_path_entry( instance );
-		g_signal_connect(
+		base_window_signal_connect(
+				BASE_WINDOW( instance ),
 				G_OBJECT( path_entry ),
 				"changed",
-				G_CALLBACK( on_path_changed ),
-				instance );
+				G_CALLBACK( on_path_changed ));
 
 		path_button = get_path_button( instance );
-		g_signal_connect(
+		base_window_signal_connect(
+				BASE_WINDOW( instance ),
 				G_OBJECT( path_button ),
 				"clicked",
-				G_CALLBACK( on_path_browse ),
-				instance );
+				G_CALLBACK( on_path_browse ));
 
 		parameters_entry = get_parameters_entry( instance );
-		g_signal_connect(
+		base_window_signal_connect(
+				BASE_WINDOW( instance ),
 				G_OBJECT( parameters_entry ),
 				"changed",
-				G_CALLBACK( on_parameters_changed ),
-				instance );
+				G_CALLBACK( on_parameters_changed ));
 
 		legend_button = get_legend_button( instance );
-		g_signal_connect(
+		base_window_signal_connect(
+				BASE_WINDOW( instance ),
 				G_OBJECT( legend_button ),
 				"clicked",
-				G_CALLBACK( on_legend_clicked ),
-				instance );
+				G_CALLBACK( on_legend_clicked ));
 
-		g_signal_connect(
+		base_window_signal_connect(
+				BASE_WINDOW( instance ),
 				G_OBJECT( instance ),
-				TAB_UPDATABLE_SIGNAL_SELECTION_CHANGED,
-				G_CALLBACK( on_tab_updatable_selection_changed ),
-				instance );
+				MAIN_WINDOW_SIGNAL_SELECTION_CHANGED,
+				G_CALLBACK( on_tab_updatable_selection_changed ));
 
-		g_signal_connect(
+		base_window_signal_connect(
+				BASE_WINDOW( instance ),
 				G_OBJECT( instance ),
 				IACTIONS_LIST_SIGNAL_COLUMN_EDITED,
-				G_CALLBACK( on_iactions_list_column_edited ),
-				instance );
+				G_CALLBACK( on_iactions_list_column_edited ));
 	}
 }
 
@@ -292,29 +293,6 @@ nact_icommand_tab_dispose( NactICommandTab *instance )
 	}
 }
 
-/**
- * A profile can only be saved if it has at least a label.
- * Returns TRUE if the label of the profile is not empty.
- */
-gboolean
-nact_icommand_tab_has_label( NactICommandTab *instance )
-{
-	gboolean has_label = FALSE;
-	GtkWidget *label_entry;
-	const gchar *label;
-
-	g_return_val_if_fail( NACT_IS_ICOMMAND_TAB( instance ), FALSE );
-
-	if( st_initialized && !st_finalized ){
-
-		label_entry = get_label_entry( instance );
-		label = gtk_entry_get_text( GTK_ENTRY( label_entry ));
-		has_label = ( g_utf8_strlen( label, -1 ) > 0 );
-	}
-
-	return( has_label );
-}
-
 static void
 on_iactions_list_column_edited( NactICommandTab *instance, NAObject *object, gchar *text, gint column )
 {
@@ -340,35 +318,59 @@ on_tab_updatable_selection_changed( NactICommandTab *instance, gint count_select
 	gboolean enable_tab;
 	GtkWidget *label_entry, *path_entry, *parameters_entry;
 	gchar *label, *path, *parameters;
+	gboolean editable;
+	GtkButton *path_button;
+	GtkButton *legend_button;
 
 	g_debug( "%s: instance=%p, count_selected=%d", thisfn, ( void * ) instance, count_selected );
 	g_return_if_fail( NACT_IS_ICOMMAND_TAB( instance ));
 
 	if( st_initialized && !st_finalized ){
 
+		st_on_selection_change = TRUE;
+
 		g_object_get(
 				G_OBJECT( instance ),
 				TAB_UPDATABLE_PROP_EDITED_ACTION, &item,
 				TAB_UPDATABLE_PROP_EDITED_PROFILE, &profile,
+				TAB_UPDATABLE_PROP_EDITABLE, &editable,
 				NULL );
 
 		enable_tab = tab_set_sensitive( instance );
 
 		label_entry = get_label_entry( instance );
 		label = profile ? na_object_get_label( profile ) : g_strdup( "" );
+		label = label ? label : g_strdup( "" );
 		gtk_entry_set_text( GTK_ENTRY( label_entry ), label );
 		check_for_label( instance, GTK_ENTRY( label_entry ), label );
 		g_free( label );
+		gtk_widget_set_sensitive( label_entry, profile != NULL );
+		nact_gtk_utils_set_editable( GTK_OBJECT( label_entry ), editable );
 
 		path_entry = get_path_entry( instance );
-		path = profile ? na_object_profile_get_path( profile ) : g_strdup( "" );
+		path = profile ? na_object_get_path( profile ) : g_strdup( "" );
+		path = path ? path : g_strdup( "" );
 		gtk_entry_set_text( GTK_ENTRY( path_entry ), path );
 		g_free( path );
+		gtk_widget_set_sensitive( path_entry, profile != NULL );
+		nact_gtk_utils_set_editable( GTK_OBJECT( path_entry ), editable );
+
+		path_button = get_path_button( instance );
+		gtk_widget_set_sensitive( GTK_WIDGET( path_button ), profile != NULL );
+		nact_gtk_utils_set_editable( GTK_OBJECT( path_button ), editable );
 
 		parameters_entry = get_parameters_entry( instance );
-		parameters = profile ? na_object_profile_get_parameters( profile ) : g_strdup( "" );
+		parameters = profile ? na_object_get_parameters( profile ) : g_strdup( "" );
+		parameters = parameters ? parameters : g_strdup( "" );
 		gtk_entry_set_text( GTK_ENTRY( parameters_entry ), parameters );
 		g_free( parameters );
+		gtk_widget_set_sensitive( parameters_entry, profile != NULL );
+		nact_gtk_utils_set_editable( GTK_OBJECT( parameters_entry ), editable );
+
+		legend_button = get_legend_button( instance );
+		gtk_widget_set_sensitive( GTK_WIDGET( legend_button ), profile != NULL );
+
+		st_on_selection_change = FALSE;
 	}
 }
 
@@ -503,16 +505,19 @@ on_label_changed( GtkEntry *entry, NactICommandTab *instance )
 	NAObjectProfile *edited;
 	const gchar *label;
 
-	g_object_get(
-			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_EDITED_PROFILE, &edited,
-			NULL );
+	if( !st_on_selection_change ){
 
-	if( edited ){
-		label = gtk_entry_get_text( entry );
-		na_object_set_label( edited, label );
-		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, edited, TRUE );
-		check_for_label( instance, entry, label );
+		g_object_get(
+				G_OBJECT( instance ),
+				TAB_UPDATABLE_PROP_EDITED_PROFILE, &edited,
+				NULL );
+
+		if( edited ){
+			label = gtk_entry_get_text( entry );
+			na_object_set_label( edited, label );
+			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, edited, TRUE );
+			check_for_label( instance, entry, label );
+		}
 	}
 }
 
@@ -532,17 +537,19 @@ on_parameters_changed( GtkEntry *entry, NactICommandTab *instance )
 {
 	NAObjectProfile *edited;
 
-	g_object_get(
-			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_EDITED_PROFILE, &edited,
-			NULL );
+	if( !st_on_selection_change ){
 
-	if( edited ){
-		na_object_profile_set_parameters( edited, gtk_entry_get_text( entry ));
-		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, edited, FALSE );
+		g_object_get(
+				G_OBJECT( instance ),
+				TAB_UPDATABLE_PROP_EDITED_PROFILE, &edited,
+				NULL );
+
+		if( edited ){
+			na_object_set_parameters( edited, gtk_entry_get_text( entry ));
+			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, edited, FALSE );
+			update_example_label( instance, edited );
+		}
 	}
-
-	update_example_label( instance, edited );
 }
 
 static void
@@ -551,7 +558,7 @@ on_path_browse( GtkButton *button, NactICommandTab *instance )
 	gboolean set_current_location = FALSE;
 	gchar *uri = NULL;
 	NactApplication *application;
-	NAPivot *pivot;
+	NAUpdater *updater;
 	GtkWindow *toplevel;
 	GtkWidget *dialog;
 	GtkWidget *path_entry;
@@ -559,7 +566,7 @@ on_path_browse( GtkButton *button, NactICommandTab *instance )
 	gchar *filename;
 
 	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( instance )));
-	pivot = nact_application_get_pivot( application );
+	updater = nact_application_get_updater( application );
 	toplevel = base_window_get_toplevel( BASE_WINDOW( instance ));
 
 	dialog = gtk_file_chooser_dialog_new(
@@ -580,7 +587,7 @@ on_path_browse( GtkButton *button, NactICommandTab *instance )
 		set_current_location = gtk_file_chooser_set_filename( GTK_FILE_CHOOSER( dialog ), path );
 
 	} else {
-		uri = na_iprefs_read_string( NA_IPREFS( pivot ), IPREFS_FOLDER_URI, "file:///bin" );
+		uri = na_iprefs_read_string( NA_IPREFS( updater ), IPREFS_FOLDER_URI, "file:///bin" );
 		gtk_file_chooser_set_current_folder_uri( GTK_FILE_CHOOSER( dialog ), uri );
 		g_free( uri );
 	}
@@ -592,7 +599,7 @@ on_path_browse( GtkButton *button, NactICommandTab *instance )
 	  }
 
 	uri = gtk_file_chooser_get_current_folder_uri( GTK_FILE_CHOOSER( dialog ));
-	na_iprefs_write_string( NA_IPREFS( pivot ), IPREFS_FOLDER_URI, uri );
+	nact_iprefs_write_string( BASE_WINDOW( instance ), IPREFS_FOLDER_URI, uri );
 	g_free( uri );
 
 	base_iprefs_save_named_window_position( BASE_WINDOW( instance ), GTK_WINDOW( dialog ), IPREFS_COMMAND_CHOOSER );
@@ -605,17 +612,20 @@ on_path_changed( GtkEntry *entry, NactICommandTab *instance )
 {
 	NAObjectProfile *edited;
 
-	g_object_get(
-			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_EDITED_PROFILE, &edited,
-			NULL );
+	if( !st_on_selection_change ){
 
-	if( edited ){
-		na_object_profile_set_path( edited, gtk_entry_get_text( entry ));
-		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, edited, FALSE );
+		g_object_get(
+				G_OBJECT( instance ),
+				TAB_UPDATABLE_PROP_EDITED_PROFILE, &edited,
+				NULL );
+
+		if( edited ){
+
+			na_object_set_path( edited, gtk_entry_get_text( entry ));
+			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, edited, FALSE );
+			update_example_label( instance, edited );
+		}
 	}
-
-	update_example_label( instance, edited );
 }
 
 /*
@@ -661,6 +671,7 @@ parse_parameters( NactICommandTab *instance )
 	gboolean is_file, is_dir;
 	gboolean accept_multiple;
 	GSList *scheme_list;
+	guint iter_inc;
 
 	const gchar *command = gtk_entry_get_text( GTK_ENTRY( get_path_entry( instance )));
 	const gchar *param_template = gtk_entry_get_text( GTK_ENTRY( get_parameters_entry( instance )));
@@ -683,20 +694,20 @@ parse_parameters( NactICommandTab *instance )
 	if( accept_multiple ){
 		if( is_file && is_dir ){
 			ex_one = ex_files[0];
-			ex_list = na_utils_gstring_joinv( NULL, " ", ex_mixed );
-			ex_path_list = na_utils_gstring_joinv( start, separator, ex_mixed );
+			ex_list = na_core_utils_gstring_joinv( NULL, " ", ex_mixed );
+			ex_path_list = na_core_utils_gstring_joinv( start, separator, ex_mixed );
 			ex_uri_list = g_strjoin( " ", ex_uri_file1, ex_uri_folder1, NULL );
 
 		} else if( is_dir ){
 			ex_one = ex_dirs[0];
-			ex_list = na_utils_gstring_joinv( NULL, " ", ex_dirs );
-			ex_path_list = na_utils_gstring_joinv( start, separator, ex_dirs );
+			ex_list = na_core_utils_gstring_joinv( NULL, " ", ex_dirs );
+			ex_path_list = na_core_utils_gstring_joinv( start, separator, ex_dirs );
 			ex_uri_list = g_strjoin( " ", ex_uri_folder1, ex_uri_folder2, NULL );
 
 		} else if( is_file ){
 			ex_one = ex_files[0];
-			ex_list = na_utils_gstring_joinv( NULL, " ", ex_files );
-			ex_path_list = na_utils_gstring_joinv( start, separator, ex_files );
+			ex_list = na_core_utils_gstring_joinv( NULL, " ", ex_files );
+			ex_path_list = na_core_utils_gstring_joinv( start, separator, ex_files );
 			ex_uri_list = g_strjoin( " ", ex_uri_file1, ex_uri_file2, NULL );
 		}
 	} else {
@@ -734,6 +745,7 @@ parse_parameters( NactICommandTab *instance )
 
 	while(( iter = g_strstr_len( iter, strlen( iter ), "%" ))){
 		tmp_string = g_string_append_len( tmp_string, old_iter, strlen( old_iter ) - strlen( iter ));
+		iter_inc = 1;
 		switch( iter[1] ){
 
 			case 'd': /* base dir of the (first) selected file(s)/folder(s) */
@@ -781,13 +793,17 @@ parse_parameters( NactICommandTab *instance )
 			case '%': /* a percent sign */
 				tmp_string = g_string_append_c( tmp_string, '%' );
 				break;
+
+			default:
+				iter_inc = 1;
+				break;
 		}
-		iter+=2; /* skip the % sign and the character after. */
-		old_iter = iter; /* store the new start of the string */
+		iter += iter_inc;				/* skip the % sign and the character after. */
+		old_iter = iter;				/* store the new start of the string */
 	}
 	tmp_string = g_string_append_len( tmp_string, old_iter, strlen( old_iter ));
 
-	na_utils_free_string_list( scheme_list );
+	na_core_utils_slist_free( scheme_list );
 
 	g_free( ex_list );
 	g_free( ex_path_list );
@@ -798,12 +814,14 @@ parse_parameters( NactICommandTab *instance )
 }
 
 static void
-set_label_label( NactICommandTab *instance, const gchar *color )
+set_label_label( NactICommandTab *instance, const gchar *color_str )
 {
-	GtkWidget *label = base_window_get_widget( BASE_WINDOW( instance ), "ProfileLabelLabel" );
-	/* i18n: label in front of the GtkEntry where user enters the profile label */
-	gchar *text = g_markup_printf_escaped( "<span color=\"%s\">%s</span>", color, _( "_Label :" ));
-	gtk_label_set_markup_with_mnemonic( GTK_LABEL( label ), text );
+	GtkWidget *label;
+	GdkColor color;
+
+	label = base_window_get_widget( BASE_WINDOW( instance ), "ProfileLabelLabel" );
+	gdk_color_parse( color_str, &color );
+	gtk_widget_modify_fg( label, GTK_STATE_NORMAL, &color );
 }
 
 static void
@@ -818,6 +836,7 @@ update_example_label( NactICommandTab *instance, NAObjectProfile *profile )
 
 	if( profile ){
 		parameters = parse_parameters( instance );
+		/*g_debug( "%s: parameters=%s", thisfn, parameters );*/
 
 		/* convert special xml chars (&, <, >,...) to avoid warnings
 		 * generated by Pango parser
