@@ -4,7 +4,7 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -34,6 +34,14 @@
 
 #include "nact-main-tab.h"
 
+/**
+ * nact_main_tab_enable_page:
+ * @window: the #NactMainWindow.
+ * @num_page: the page number, starting from zero.
+ * @enabled: whether the tab should be set sensitive or not.
+ *
+ * Set the sensitivity of the tab.
+ */
 void
 nact_main_tab_enable_page( NactMainWindow *window, gint num_page, gboolean enabled )
 {
@@ -47,3 +55,31 @@ nact_main_tab_enable_page( NactMainWindow *window, gint num_page, gboolean enabl
 	label = gtk_notebook_get_tab_label( notebook, page );
 	gtk_widget_set_sensitive( label, enabled );
 }
+
+/**
+ * nact_main_tab_is_page_enabled:
+ * @window: the #NactMainWindow.
+ * @num_page: the page number, starting from zero.
+ *
+ * Returns: %TRUE if the tab is sensitive, %FALSE else.
+ */
+gboolean
+nact_main_tab_is_page_enabled( NactMainWindow *window, gint num_page )
+{
+	gboolean is_sensitive;
+	GtkNotebook *notebook;
+	GtkWidget *page;
+
+	notebook = GTK_NOTEBOOK( base_window_get_widget( BASE_WINDOW( window ), "MainNotebook" ));
+	page = gtk_notebook_get_nth_page( notebook, num_page );
+
+#if(( GTK_MAJOR_VERSION > 2 ) || ( GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION > 18 ))
+	is_sensitive = gtk_widget_is_sensitive( page );
+#else
+	is_sensitive = GTK_WIDGET_IS_SENSITIVE( page );
+#endif
+
+	g_debug( "nact_main_tab_is_page_enabled: num_page=%d, is_sensitive=%s", num_page, is_sensitive ? "True":"False" );
+
+	return( is_sensitive );
+}
