@@ -4,7 +4,7 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -35,11 +35,12 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
-#include <runtime/na-iio-provider.h>
+#include <api/na-core-utils.h>
+#include <api/na-iio-provider.h>
+#include <api/na-object-api.h>
 
-#include <common/na-object-api.h>
-#include <common/na-iprefs.h>
-#include <common/na-utils.h>
+#include <core/na-io-provider.h>
+#include <core/na-iprefs.h>
 
 #include "nact-application.h"
 #include "nact-window.h"
@@ -124,7 +125,8 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	static const gchar *thisfn = "nact_window_instance_init";
 	NactWindow *self;
 
-	g_debug( "%s: instance=%p, klass=%p", thisfn, ( void * ) instance, ( void * ) klass );
+	g_debug( "%s: instance=%p (%s), klass=%p",
+			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
 	g_return_if_fail( NACT_IS_WINDOW( instance ));
 	self = NACT_WINDOW( instance );
 
@@ -139,7 +141,7 @@ instance_dispose( GObject *window )
 	static const gchar *thisfn = "nact_window_instance_dispose";
 	NactWindow *self;
 
-	g_debug( "%s: window=%p", thisfn, ( void * ) window );
+	g_debug( "%s: window=%p (%s)", thisfn, ( void * ) window, G_OBJECT_TYPE_NAME( window ));
 	g_return_if_fail( NACT_IS_WINDOW( window ));
 	self = NACT_WINDOW( window );
 
@@ -173,26 +175,133 @@ instance_finalize( GObject *window )
 }
 
 /**
- * Returns a pointer to the list of actions.
+ * nact_window_has_writable_providers:
+ * @window: this #NactWindow instance.
+ *
+ * Returns: %TRUE if at least one I/O provider is writable, %FALSE else.
  */
-NAPivot *
-nact_window_get_pivot( NactWindow *window )
+gboolean
+nact_window_has_writable_providers( NactWindow *window )
 {
-	NAPivot *pivot = NULL;
+	gboolean has_writables;
 	NactApplication *application;
+	NAUpdater *updater;
+	NAIOProvider *provider;
 
-	g_return_val_if_fail( NACT_IS_WINDOW( window ), NULL );
+	has_writables = FALSE;
+
+	g_return_val_if_fail( NACT_IS_WINDOW( window ), has_writables );
 
 	if( !window->private->dispose_has_run ){
 
-		g_object_get( G_OBJECT( window ), BASE_WINDOW_PROP_APPLICATION, &application, NULL );
-		g_return_val_if_fail( NACT_IS_APPLICATION( application ), NULL );
+		application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
+		updater = nact_application_get_updater( application );
+		provider = na_io_provider_get_writable_provider( NA_PIVOT( updater ));
 
-		pivot = nact_application_get_pivot( application );
-		g_return_val_if_fail( NA_IS_PIVOT( pivot ), NULL );
+		if( provider ){
+			has_writables = TRUE;
+		}
 	}
 
-	return( pivot );
+	return( has_writables );
+}
+
+/**
+ * nact_window_is_item_writable:
+ * @window: this #NactWindow object.
+ * @item: the #NAObjectItem to be evaluated.
+ * @reason: the reason for what @item may not be writable.
+ *
+ * Returns: %TRUE: if @item is actually writable, given the current
+ * status of its provider, %FALSE else.
+ *
+ * For an item be actually writable:
+ * - the item must not be itself in a read-only store, which has been
+ *   checked when first reading it
+ * - the provider must be willing (resp. able) to write
+ * - the provider must not has been locked by the admin
+ * - the writability of the provider must not have been removed by the user
+ * - the whole configuration must not have been locked by the admin.
+ */
+gboolean
+nact_window_is_item_writable( const NactWindow *window, const NAObjectItem *item, guint *reason )
+{
+	gboolean writable;
+	NactApplication *application;
+	NAUpdater *updater;
+	NAIOProvider *provider;
+
+	g_return_val_if_fail( NA_IS_OBJECT_ITEM( item ), FALSE );
+
+	writable = FALSE;
+	if( reason ){
+		*reason = NA_IIO_PROVIDER_STATUS_UNDETERMINED;
+	}
+
+	if( !window->private->dispose_has_run ){
+
+		application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
+		updater = nact_application_get_updater( application );
+
+		writable = TRUE;
+		if( reason ){
+			*reason = NA_IIO_PROVIDER_STATUS_WRITABLE;
+		}
+
+		if( writable ){
+			if( na_object_is_readonly( item )){
+				writable = FALSE;
+				if( reason ){
+					*reason = NA_IIO_PROVIDER_STATUS_ITEM_READONLY;
+				}
+			}
+		}
+
+		if( writable ){
+			provider = na_object_get_provider( item );
+			if( provider ){
+				if( !na_io_provider_is_willing_to_write( provider )){
+					writable = FALSE;
+					if( reason ){
+						*reason = NA_IIO_PROVIDER_STATUS_PROVIDER_NOT_WILLING_TO;
+					}
+				} else if( na_io_provider_is_locked_by_admin( provider, NA_IPREFS( updater ))){
+					writable = FALSE;
+					if( reason ){
+						*reason = NA_IIO_PROVIDER_STATUS_PROVIDER_LOCKED_BY_ADMIN;
+					}
+				} else if( !na_io_provider_is_user_writable( provider, NA_IPREFS( updater ))){
+					writable = FALSE;
+					if( reason ){
+						*reason = NA_IIO_PROVIDER_STATUS_PROVIDER_LOCKED_BY_USER;
+					}
+				} else if( na_pivot_is_configuration_locked_by_admin( NA_PIVOT( updater ))){
+					writable = FALSE;
+					if( reason ){
+						*reason = NA_IIO_PROVIDER_STATUS_CONFIGURATION_LOCKED_BY_ADMIN;
+					}
+				} else if( !na_io_provider_has_write_api( provider )){
+					writable = FALSE;
+					if( reason ){
+						*reason = NA_IIO_PROVIDER_STATUS_NO_API;
+					}
+				}
+
+			/* the get_writable_provider() api already takes above checks
+			 */
+			} else {
+				provider = na_io_provider_get_writable_provider( NA_PIVOT( updater ));
+				if( !provider ){
+					writable = FALSE;
+					if( reason ){
+						*reason = NA_IIO_PROVIDER_STATUS_NO_PROVIDER_FOUND;
+					}
+				}
+			}
+		}
+	}
+
+	return( writable );
 }
 
 /**
@@ -213,9 +322,11 @@ nact_window_save_item( NactWindow *window, NAObjectItem *item )
 {
 	static const gchar *thisfn = "nact_window_save_item";
 	gboolean save_ok = FALSE;
-	NAPivot *pivot;
-	gchar *msg = NULL;
+	NactApplication *application;
+	NAUpdater *updater;
+	GSList *messages = NULL;
 	guint ret;
+	gchar *msgerr;
 
 	g_debug( "%s: window=%p, item=%p (%s)", thisfn,
 			( void * ) window, ( void * ) item, G_OBJECT_TYPE_NAME( item ));
@@ -224,21 +335,32 @@ nact_window_save_item( NactWindow *window, NAObjectItem *item )
 
 	if( !window->private->dispose_has_run ){
 
-		pivot = nact_window_get_pivot( window );
-		g_assert( NA_IS_PIVOT( pivot ));
+		application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
+		updater = nact_application_get_updater( application );
 
-		na_object_dump( item );
+		ret = na_updater_write_item( updater, item, &messages );
+		g_debug( "nact_window_save_item: ret=%d", ret );
 
-		ret = na_pivot_write_item( pivot, NA_OBJECT( item ), &msg );
+		msgerr = NULL;
 
-		if( msg ){
-			base_window_error_dlg(
-					BASE_WINDOW( window ),
-					GTK_MESSAGE_WARNING, _( "An error has occured when trying to save the item" ), msg );
-			g_free( msg );
+		if( messages ){
+			msgerr = na_core_utils_slist_join_at_end( messages, "\n" );
+			na_core_utils_slist_free( messages );
+
+		} else if( ret != NA_IIO_PROVIDER_CODE_OK ){
+			msgerr = na_io_provider_get_return_code_label( ret );
 		}
 
-		save_ok = ( ret == NA_IIO_PROVIDER_WRITE_OK );
+		if( msgerr ){
+			base_window_error_dlg(
+					BASE_WINDOW( window ),
+					GTK_MESSAGE_WARNING,
+					_( "An error has occured when trying to save the item" ),
+					msgerr );
+			g_free( msgerr );
+		}
+
+		save_ok = ( ret == NA_IIO_PROVIDER_CODE_OK );
 	}
 
 	return( save_ok );
@@ -252,12 +374,13 @@ nact_window_save_item( NactWindow *window, NAObjectItem *item )
  * Deleted an item from the I/O storage subsystem.
  */
 gboolean
-nact_window_delete_item( NactWindow *window, NAObjectItem *item )
+nact_window_delete_item( NactWindow *window, const NAObjectItem *item )
 {
 	static const gchar *thisfn = "nact_window_delete_item";
 	gboolean delete_ok = FALSE;
-	NAPivot *pivot;
-	gchar *msg = NULL;
+	NactApplication *application;
+	NAUpdater *updater;
+	GSList *messages = NULL;
 	guint ret;
 
 	g_debug( "%s: window=%p, item=%p (%s)", thisfn,
@@ -267,21 +390,23 @@ nact_window_delete_item( NactWindow *window, NAObjectItem *item )
 
 	if( !window->private->dispose_has_run ){
 
-		pivot = nact_window_get_pivot( window );
-		g_assert( NA_IS_PIVOT( pivot ));
+		application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
+		updater = nact_application_get_updater( application );
 
 		na_object_dump_norec( item );
 
-		ret = na_pivot_delete_item( pivot, NA_OBJECT( item ), &msg );
+		ret = na_updater_delete_item( updater, item, &messages );
 
-		if( msg ){
+		if( messages ){
 			base_window_error_dlg(
 					BASE_WINDOW( window ),
-					GTK_MESSAGE_WARNING, _( "An error has occured when trying to delete the item" ), msg );
-			g_free( msg );
+					GTK_MESSAGE_WARNING,
+					_( "An error has occured when trying to delete the item" ),
+					( const gchar * ) messages->data );
+			na_core_utils_slist_free( messages );
 		}
 
-		delete_ok = ( ret == NA_IIO_PROVIDER_WRITE_OK );
+		delete_ok = ( ret == NA_IIO_PROVIDER_CODE_OK );
 	}
 
 	return( delete_ok );
