@@ -4,7 +4,7 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -40,8 +40,7 @@
  * It is a common base class for all Nautilus Actions window documents.
  */
 
-#include <runtime/na-object-item-class.h>
-#include <runtime/na-pivot.h>
+#include <api/na-object-item.h>
 
 #include "base-window.h"
 
@@ -54,7 +53,7 @@ G_BEGIN_DECLS
 #define NACT_IS_WINDOW_CLASS( klass )	( G_TYPE_CHECK_CLASS_TYPE(( klass ), NACT_WINDOW_TYPE ))
 #define NACT_WINDOW_GET_CLASS( object )	( G_TYPE_INSTANCE_GET_CLASS(( object ), NACT_WINDOW_TYPE, NactWindowClass ))
 
-typedef struct NactWindowPrivate NactWindowPrivate;
+typedef struct NactWindowPrivate      NactWindowPrivate;
 
 typedef struct {
 	BaseWindow         parent;
@@ -70,16 +69,18 @@ typedef struct {
 }
 	NactWindowClass;
 
-GType    nact_window_get_type( void );
+GType      nact_window_get_type( void );
 
-NAPivot *nact_window_get_pivot( NactWindow *window );
+gboolean   nact_window_has_writable_providers( NactWindow *window );
 
-gboolean nact_window_save_item( NactWindow *window, NAObjectItem *item );
-gboolean nact_window_delete_item( NactWindow *window, NAObjectItem *item );
+gboolean   nact_window_is_item_writable( const NactWindow *window, const NAObjectItem *item, guint *reason );
 
-void     nact_window_count_level_zero_items( GList *items, guint *actions, guint *profiles, guint *menus );
+gboolean   nact_window_save_item  ( NactWindow *window, NAObjectItem *item );
+gboolean   nact_window_delete_item( NactWindow *window, const NAObjectItem *item );
 
-gboolean nact_window_warn_modified( NactWindow *window );
+void       nact_window_count_level_zero_items( GList *items, guint *actions, guint *profiles, guint *menus );
+
+gboolean   nact_window_warn_modified( NactWindow *window );
 
 G_END_DECLS
 
